@@ -456,7 +456,7 @@ class NSGA3:
         # Calculate statistics before starting optimization
         parents = self.population['X']
         f_new = self.obj_func(parents)
-        mdr = self._calculate_mdr(f_new,f_new)
+        mdr = tf.zeros((), dtype=tf.float64)
         refs = self._calculate_filled_references(f_new)
 
         if self.verbose: print('Generation 0 – MDR {} – Ref dirs {}%     '.format(np.round(mdr.numpy(),2),np.round(100*refs.numpy())), end = '\r')
